@@ -1,17 +1,18 @@
 package File::Patch::Undoable;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.05'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Builtin::Logged qw(system);
 use Capture::Tiny qw(capture);
 use File::Temp qw(tempfile);
 use Proc::ChildError qw(explain_child_error);
 
-our $VERSION = '0.04'; # VERSION
-
 our %SPEC;
 
 sub _check_patch_has_dry_run_option {
@@ -177,15 +178,32 @@ File::Patch::Undoable - Patch a file, with undo support
 
 =head1 VERSION
 
-This document describes version 0.04 of File::Patch::Undoable (from Perl distribution File-Patch-Undoable), released on 2014-05-28.
+This document describes version 0.05 of File::Patch::Undoable (from Perl distribution File-Patch-Undoable), released on 2015-08-17.
+
+=head1 FAQ
+
+=head2 Why use the patch program? Why not use a Perl module like Text::Patch?
+
+The B<patch> program has many nice features that L<Text::Patch> lacks, e.g.
+applying reverse patch (needed to check fixed state and to undo), autodetection
+of patch type, ignoring whitespace and fuzz factor, etc.
+
+=head1 KNOWN ISSUES
+
+=head1 SEE ALSO
+
+L<Rinci::Transaction>
+
+L<Text::Patch>, L<PatchReader>, L<Text::Patch::Rred>
 
 =head1 FUNCTIONS
 
 
 =head2 patch(%args) -> [status, msg, result, meta]
 
-Patch a file, with undo support.
+{en_US Patch a file, with undo support}.
 
+{en_US 
 On do, will patch file with the supplied patch. On undo, will apply the reverse
 of the patch.
 
@@ -199,6 +217,7 @@ allowed).
 Fixed state: file exists, patch file exists, and patch has been applied.
 
 Fixable state: file exists, patch file exists, and patch has not been applied.
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -209,17 +228,19 @@ Arguments ('*' denotes required arguments):
 
 =item * B<file>* => I<str>
 
-Path to file to be patched.
+{en_US Path to file to be patched}.
 
 =item * B<patch>* => I<str>
 
-Path to patch file.
+{en_US Path to patch file}.
 
+{en_US 
 Patch can be in unified or context format, it will be autodetected.
+}
 
 =item * B<reverse> => I<bool> (default: 0)
 
-Whether to apply reverse of patch.
+{en_US Whether to apply reverse of patch}.
 
 =back
 
@@ -249,8 +270,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -260,21 +279,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-=head1 FAQ
-
-=head2 Why use the patch program? Why not use a Perl module like Text::Patch?
-
-The B<patch> program has many nice features that L<Text::Patch> lacks, e.g.
-applying reverse patch (needed to check fixed state and to undo), autodetection
-of patch type, ignoring whitespace and fuzz factor, etc.
-
-=head1 KNOWN ISSUES
-
-=head1 SEE ALSO
-
-L<Rinci::Transaction>
-
-L<Text::Patch>, L<PatchReader>, L<Text::Patch::Rred>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -294,11 +299,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
